import { Directive, ElementRef, Input, HostListener, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ResponsiveElementDirective {
    /**
     * @param {?} hostElement
     */
    constructor(hostElement) {
        this.hostElement = hostElement;
        this.sizeMap = null;
        this.defaultCssClass = 'default';
        this.oldCssClass = null;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.onResize(null);
    }
    /**
     * @param {?} elementSize
     * @return {?}
     */
    recalcClass(elementSize) {
        if (!this.sizeMap) {
            return this.defaultCssClass;
        }
        /** @type {?} */
        const orderedKeys = Object.keys(this.sizeMap);
        /** @type {?} */
        const numberOfEntries = orderedKeys.length;
        for (let index = 0; index < numberOfEntries; index++) {
            /** @type {?} */
            const minSize = +orderedKeys[index];
            if (index <= numberOfEntries - 2) {
                /** @type {?} */
                const maxSize = +orderedKeys[index + 1];
                if (elementSize >= minSize && elementSize < maxSize) {
                    return this.sizeMap[minSize];
                }
            }
            else if (index === numberOfEntries - 1 &&
                elementSize >= minSize) {
                return this.sizeMap[minSize];
            }
        }
        return this.defaultCssClass;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onResize(event) {
        if (this.hostElement && this.hostElement.nativeElement) {
            /** @type {?} */
            const newCssClass = this.recalcClass(this.hostElement.nativeElement.clientWidth);
            if (this.oldCssClass !== newCssClass) {
                if (this.oldCssClass !== null) {
                    this.hostElement.nativeElement.classList.remove(this.oldCssClass);
                }
                this.hostElement.nativeElement.classList.add(newCssClass);
                this.oldCssClass = newCssClass;
            }
        }
    }
}
ResponsiveElementDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngxReResponsiveElement]',
            },] }
];
/** @nocollapse */
ResponsiveElementDirective.ctorParameters = () => [
    { type: ElementRef }
];
ResponsiveElementDirective.propDecorators = {
    sizeMap: [{ type: Input }],
    defaultCssClass: [{ type: Input }],
    onResize: [{ type: HostListener, args: ['window:resize', ['$event'],] }]
};
if (false) {
    /** @type {?} */
    ResponsiveElementDirective.prototype.sizeMap;
    /** @type {?} */
    ResponsiveElementDirective.prototype.defaultCssClass;
    /** @type {?} */
    ResponsiveElementDirective.prototype.oldCssClass;
    /**
     * @type {?}
     * @private
     */
    ResponsiveElementDirective.prototype.hostElement;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxResponsiveElementsModule {
}
NgxResponsiveElementsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ResponsiveElementDirective],
                imports: [],
                exports: [ResponsiveElementDirective],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NgxResponsiveElementsModule, ResponsiveElementDirective as ɵa };
//# sourceMappingURL=ngx-responsive-elements.js.map
